function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext } from 'react';
import clsx from 'clsx';
import { makeStyles, useTheme } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';
import { useIntl } from 'react-intl';
import OnlineContext from 'base-shell/lib/providers/Online/Context';
import MenuContext from 'material-ui-shell/lib/providers/Menu/Context';
import LinearProgress from '@material-ui/core/LinearProgress';
import ChevronLeft from '@material-ui/icons/ChevronLeft';
import ConfigContext from 'base-shell/lib/providers/Config/Context';
var useStyles = makeStyles(function (theme) {
  return {
    root: {
      width: '100%',
      display: 'flex',
      flexDirection: 'column',
      height: '100vh',
      overflow: 'hidden'
    },
    appBar: {
      zIndex: theme.zIndex.drawer + 1,
      transition: theme.transitions.create(['width', 'margin'], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.leavingScreen
      }),
      maxHeight: 64
    },
    appBarShift: {
      width: function width(props) {
        return "calc(100% - " + props.width + "px)";
      },
      transition: theme.transitions.create(['width', 'margin'], {
        easing: theme.transitions.easing.sharp,
        duration: theme.transitions.duration.enteringScreen
      })
    },
    menuButton: {
      marginLeft: -12
    },
    hide: {
      display: 'none'
    },
    toolbar: _extends({
      alignItems: 'center',
      justifyContent: 'flex-end'
    }, theme.mixins.toolbar),
    offlineIndicator: {
      position: 'absolute',
      display: 'flex',
      alignItems: 'center',
      backgroundColor: theme.palette.secondary.main,
      justifyContent: 'center',
      right: 0,
      left: 0,
      height: function height(props) {
        return props.offlineIndicatorHeight;
      }
    },
    content: {
      flex: 1,
      overflow: 'auto'
    },
    grow: {
      flex: '1 1 auto'
    }
  };
});

var Page = function Page(_ref) {
  var children = _ref.children,
      pageTitle = _ref.pageTitle,
      onBackClick = _ref.onBackClick,
      isLoading = _ref.isLoading;
  var isOnline = useContext(OnlineContext);
  var theme = useTheme();

  var _useContext = useContext(ConfigContext),
      appConfig = _useContext.appConfig;

  var _ref2 = appConfig || {},
      menu = _ref2.menu;

  var _ref3 = menu || {},
      _ref3$width = _ref3.width,
      width = _ref3$width === void 0 ? 240 : _ref3$width,
      _ref3$offlineIndicato = _ref3.offlineIndicatorHeight,
      offlineIndicatorHeight = _ref3$offlineIndicato === void 0 ? 12 : _ref3$offlineIndicato;

  var _useContext2 = useContext(MenuContext),
      isDesktop = _useContext2.isDesktop,
      isDesktopOpen = _useContext2.isDesktopOpen,
      setDesktopOpen = _useContext2.setDesktopOpen,
      isMobileOpen = _useContext2.isMobileOpen,
      setMobileOpen = _useContext2.setMobileOpen,
      setMini = _useContext2.setMini;

  var intl = useIntl();
  var headerTitle = '';

  if (typeof pageTitle === 'string' || pageTitle instanceof String) {
    headerTitle = pageTitle;
  }

  var classes = useStyles({
    width,
    offlineIndicatorHeight
  });

  var handleDrawerMenuClick = function handleDrawerMenuClick() {
    if (!isDesktopOpen) {
      setMini(false);
      setDesktopOpen(true);

      if (!isDesktop) {
        setMobileOpen(!isMobileOpen);
      }
    } else {
      setMobileOpen(!isMobileOpen);
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classes.root
  }, /*#__PURE__*/React.createElement(AppBar, {
    position: isDesktop ? 'absolute' : undefined,
    className: isDesktop ? clsx(classes.appBar, isDesktopOpen && classes.appBarShift) : classes.appBar
  }, /*#__PURE__*/React.createElement(Toolbar, null, /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    "aria-label": "open drawer",
    onClick: handleDrawerMenuClick,
    edge: "start",
    className: clsx(classes.menuButton, isDesktopOpen && isDesktop && classes.hide, onBackClick && classes.hide)
  }, /*#__PURE__*/React.createElement(MenuIcon, null)), /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    "aria-label": "open drawer",
    onClick: onBackClick,
    className: clsx(classes.menuButton, !onBackClick && classes.hide)
  }, /*#__PURE__*/React.createElement(ChevronLeft, null)), !onBackClick && isDesktopOpen && false && /*#__PURE__*/React.createElement("div", {
    style: {
      marginRight: 32
    }
  }), /*#__PURE__*/React.createElement(Typography, {
    variant: "h6",
    color: "inherit",
    noWrap: true
  }, headerTitle), /*#__PURE__*/React.createElement("div", {
    className: classes.grow
  }))), /*#__PURE__*/React.createElement("div", {
    className: classes.toolbar
  }), isLoading && /*#__PURE__*/React.createElement(LinearProgress, null), !isOnline && /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'flex',
      justifyContent: 'center',
      width: '100%',
      height: 15,
      backgroundColor: theme.palette.secondary.main
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "caption",
    color: "textSecondary",
    noWrap: true
  }, intl.formatMessage({
    id: 'offline',
    defaultMessage: 'Offline'
  }))), /*#__PURE__*/React.createElement("main", {
    className: classes.content
  }, children));
};

export default Page;